/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  Copyright (C) 2006-2010 XNeur Team
 *
 */

#ifndef _DETECTION_H_
#define _DETECTION_H_

#define NO_LANGUAGE	-1

#include "buffer.h"
#include "xneur.h"

int check_lang(struct _xneur_handle *handle, struct _buffer *p, int cur_lang);

int check_lang_with_similar_words(struct _xneur_handle *handle, struct _buffer *p, int cur_lang);

#endif /* _DETECTION_H_ */
